# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.ocr.v1beta1 import genesis_pb2 as injective_dot_ocr_dot_v1beta1_dot_genesis__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/ocr/v1beta1/query.proto',
  package='injective.ocr.v1beta1',
  syntax='proto3',
  serialized_options=b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!injective/ocr/v1beta1/query.proto\x12\x15injective.ocr.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a#injective/ocr/v1beta1/genesis.proto\"\x14\n\x12QueryParamsRequest\"J\n\x13QueryParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\")\n\x16QueryFeedConfigRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"\x92\x01\n\x17QueryFeedConfigResponse\x12?\n\x10\x66\x65\x65\x64_config_info\x18\x01 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfo\x12\x36\n\x0b\x66\x65\x65\x64_config\x18\x02 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig\"-\n\x1aQueryFeedConfigInfoRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"\x9d\x01\n\x1bQueryFeedConfigInfoResponse\x12?\n\x10\x66\x65\x65\x64_config_info\x18\x01 \x01(\x0b\x32%.injective.ocr.v1beta1.FeedConfigInfo\x12=\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\"*\n\x17QueryLatestRoundRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"f\n\x18QueryLatestRoundResponse\x12\x17\n\x0flatest_round_id\x18\x01 \x01(\x04\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.injective.ocr.v1beta1.Transmission\"8\n%QueryLatestTransmissionDetailsRequest\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\"\xb1\x01\n&QueryLatestTransmissionDetailsResponse\x12\x15\n\rconfig_digest\x18\x01 \x01(\x0c\x12=\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\x12\x31\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32#.injective.ocr.v1beta1.Transmission\"-\n\x16QueryOwedAmountRequest\x12\x13\n\x0btransmitter\x18\x01 \x01(\t\"J\n\x17QueryOwedAmountResponse\x12/\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x19\n\x17QueryModuleStateRequest\"N\n\x18QueryModuleStateResponse\x12\x32\n\x05state\x18\x01 \x01(\x0b\x32#.injective.ocr.v1beta1.GenesisState2\xbb\t\n\x05Query\x12\x86\x01\n\x06Params\x12).injective.ocr.v1beta1.QueryParamsRequest\x1a*.injective.ocr.v1beta1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/chainlink/ocr/v1beta1/params\x12\xa1\x01\n\nFeedConfig\x12-.injective.ocr.v1beta1.QueryFeedConfigRequest\x1a..injective.ocr.v1beta1.QueryFeedConfigResponse\"4\x82\xd3\xe4\x93\x02.\x12,/chainlink/ocr/v1beta1/feed_config/{feed_id}\x12\xb2\x01\n\x0e\x46\x65\x65\x64\x43onfigInfo\x12\x31.injective.ocr.v1beta1.QueryFeedConfigInfoRequest\x1a\x32.injective.ocr.v1beta1.QueryFeedConfigInfoResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/chainlink/ocr/v1beta1/feed_config_info/{feed_id}\x12\xa5\x01\n\x0bLatestRound\x12..injective.ocr.v1beta1.QueryLatestRoundRequest\x1a/.injective.ocr.v1beta1.QueryLatestRoundResponse\"5\x82\xd3\xe4\x93\x02/\x12-/chainlink/ocr/v1beta1/latest_round/{feed_id}\x12\xde\x01\n\x19LatestTransmissionDetails\x12<.injective.ocr.v1beta1.QueryLatestTransmissionDetailsRequest\x1a=.injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse\"D\x82\xd3\xe4\x93\x02>\x12</chainlink/ocr/v1beta1/latest_transmission_details/{feed_id}\x12\xa5\x01\n\nOwedAmount\x12-.injective.ocr.v1beta1.QueryOwedAmountRequest\x1a..injective.ocr.v1beta1.QueryOwedAmountResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/chainlink/ocr/v1beta1/owed_amount/{transmitter}\x12\x9e\x01\n\x0eOcrModuleState\x12..injective.ocr.v1beta1.QueryModuleStateRequest\x1a/.injective.ocr.v1beta1.QueryModuleStateResponse\"+\x82\xd3\xe4\x93\x02%\x12#/chainlink/ocr/v1beta1/module_stateBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,injective_dot_ocr_dot_v1beta1_dot_ocr__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,injective_dot_ocr_dot_v1beta1_dot_genesis__pb2.DESCRIPTOR,])




_QUERYPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryParamsRequest',
  full_name='injective.ocr.v1beta1.QueryParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=234,
)


_QUERYPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryParamsResponse',
  full_name='injective.ocr.v1beta1.QueryParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.ocr.v1beta1.QueryParamsResponse.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=310,
)


_QUERYFEEDCONFIGREQUEST = _descriptor.Descriptor(
  name='QueryFeedConfigRequest',
  full_name='injective.ocr.v1beta1.QueryFeedConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.QueryFeedConfigRequest.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=353,
)


_QUERYFEEDCONFIGRESPONSE = _descriptor.Descriptor(
  name='QueryFeedConfigResponse',
  full_name='injective.ocr.v1beta1.QueryFeedConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_config_info', full_name='injective.ocr.v1beta1.QueryFeedConfigResponse.feed_config_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_config', full_name='injective.ocr.v1beta1.QueryFeedConfigResponse.feed_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=502,
)


_QUERYFEEDCONFIGINFOREQUEST = _descriptor.Descriptor(
  name='QueryFeedConfigInfoRequest',
  full_name='injective.ocr.v1beta1.QueryFeedConfigInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.QueryFeedConfigInfoRequest.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=549,
)


_QUERYFEEDCONFIGINFORESPONSE = _descriptor.Descriptor(
  name='QueryFeedConfigInfoResponse',
  full_name='injective.ocr.v1beta1.QueryFeedConfigInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_config_info', full_name='injective.ocr.v1beta1.QueryFeedConfigInfoResponse.feed_config_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch_and_round', full_name='injective.ocr.v1beta1.QueryFeedConfigInfoResponse.epoch_and_round', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=709,
)


_QUERYLATESTROUNDREQUEST = _descriptor.Descriptor(
  name='QueryLatestRoundRequest',
  full_name='injective.ocr.v1beta1.QueryLatestRoundRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.QueryLatestRoundRequest.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=753,
)


_QUERYLATESTROUNDRESPONSE = _descriptor.Descriptor(
  name='QueryLatestRoundResponse',
  full_name='injective.ocr.v1beta1.QueryLatestRoundResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='latest_round_id', full_name='injective.ocr.v1beta1.QueryLatestRoundResponse.latest_round_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.ocr.v1beta1.QueryLatestRoundResponse.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=755,
  serialized_end=857,
)


_QUERYLATESTTRANSMISSIONDETAILSREQUEST = _descriptor.Descriptor(
  name='QueryLatestTransmissionDetailsRequest',
  full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsRequest.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=915,
)


_QUERYLATESTTRANSMISSIONDETAILSRESPONSE = _descriptor.Descriptor(
  name='QueryLatestTransmissionDetailsResponse',
  full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_digest', full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse.config_digest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch_and_round', full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse.epoch_and_round', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=918,
  serialized_end=1095,
)


_QUERYOWEDAMOUNTREQUEST = _descriptor.Descriptor(
  name='QueryOwedAmountRequest',
  full_name='injective.ocr.v1beta1.QueryOwedAmountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='injective.ocr.v1beta1.QueryOwedAmountRequest.transmitter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1142,
)


_QUERYOWEDAMOUNTRESPONSE = _descriptor.Descriptor(
  name='QueryOwedAmountResponse',
  full_name='injective.ocr.v1beta1.QueryOwedAmountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.ocr.v1beta1.QueryOwedAmountResponse.amount', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1218,
)


_QUERYMODULESTATEREQUEST = _descriptor.Descriptor(
  name='QueryModuleStateRequest',
  full_name='injective.ocr.v1beta1.QueryModuleStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1220,
  serialized_end=1245,
)


_QUERYMODULESTATERESPONSE = _descriptor.Descriptor(
  name='QueryModuleStateResponse',
  full_name='injective.ocr.v1beta1.QueryModuleStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.ocr.v1beta1.QueryModuleStateResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1247,
  serialized_end=1325,
)

_QUERYPARAMSRESPONSE.fields_by_name['params'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._PARAMS
_QUERYFEEDCONFIGRESPONSE.fields_by_name['feed_config_info'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._FEEDCONFIGINFO
_QUERYFEEDCONFIGRESPONSE.fields_by_name['feed_config'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._FEEDCONFIG
_QUERYFEEDCONFIGINFORESPONSE.fields_by_name['feed_config_info'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._FEEDCONFIGINFO
_QUERYFEEDCONFIGINFORESPONSE.fields_by_name['epoch_and_round'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._EPOCHANDROUND
_QUERYLATESTROUNDRESPONSE.fields_by_name['data'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._TRANSMISSION
_QUERYLATESTTRANSMISSIONDETAILSRESPONSE.fields_by_name['epoch_and_round'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._EPOCHANDROUND
_QUERYLATESTTRANSMISSIONDETAILSRESPONSE.fields_by_name['data'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._TRANSMISSION
_QUERYOWEDAMOUNTRESPONSE.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_QUERYMODULESTATERESPONSE.fields_by_name['state'].message_type = injective_dot_ocr_dot_v1beta1_dot_genesis__pb2._GENESISSTATE
DESCRIPTOR.message_types_by_name['QueryParamsRequest'] = _QUERYPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryParamsResponse'] = _QUERYPARAMSRESPONSE
DESCRIPTOR.message_types_by_name['QueryFeedConfigRequest'] = _QUERYFEEDCONFIGREQUEST
DESCRIPTOR.message_types_by_name['QueryFeedConfigResponse'] = _QUERYFEEDCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['QueryFeedConfigInfoRequest'] = _QUERYFEEDCONFIGINFOREQUEST
DESCRIPTOR.message_types_by_name['QueryFeedConfigInfoResponse'] = _QUERYFEEDCONFIGINFORESPONSE
DESCRIPTOR.message_types_by_name['QueryLatestRoundRequest'] = _QUERYLATESTROUNDREQUEST
DESCRIPTOR.message_types_by_name['QueryLatestRoundResponse'] = _QUERYLATESTROUNDRESPONSE
DESCRIPTOR.message_types_by_name['QueryLatestTransmissionDetailsRequest'] = _QUERYLATESTTRANSMISSIONDETAILSREQUEST
DESCRIPTOR.message_types_by_name['QueryLatestTransmissionDetailsResponse'] = _QUERYLATESTTRANSMISSIONDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['QueryOwedAmountRequest'] = _QUERYOWEDAMOUNTREQUEST
DESCRIPTOR.message_types_by_name['QueryOwedAmountResponse'] = _QUERYOWEDAMOUNTRESPONSE
DESCRIPTOR.message_types_by_name['QueryModuleStateRequest'] = _QUERYMODULESTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryModuleStateResponse'] = _QUERYMODULESTATERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QueryFeedConfigRequest = _reflection.GeneratedProtocolMessageType('QueryFeedConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDCONFIGREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryFeedConfigRequest)
  })
_sym_db.RegisterMessage(QueryFeedConfigRequest)

QueryFeedConfigResponse = _reflection.GeneratedProtocolMessageType('QueryFeedConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDCONFIGRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryFeedConfigResponse)
  })
_sym_db.RegisterMessage(QueryFeedConfigResponse)

QueryFeedConfigInfoRequest = _reflection.GeneratedProtocolMessageType('QueryFeedConfigInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDCONFIGINFOREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryFeedConfigInfoRequest)
  })
_sym_db.RegisterMessage(QueryFeedConfigInfoRequest)

QueryFeedConfigInfoResponse = _reflection.GeneratedProtocolMessageType('QueryFeedConfigInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDCONFIGINFORESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryFeedConfigInfoResponse)
  })
_sym_db.RegisterMessage(QueryFeedConfigInfoResponse)

QueryLatestRoundRequest = _reflection.GeneratedProtocolMessageType('QueryLatestRoundRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLATESTROUNDREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryLatestRoundRequest)
  })
_sym_db.RegisterMessage(QueryLatestRoundRequest)

QueryLatestRoundResponse = _reflection.GeneratedProtocolMessageType('QueryLatestRoundResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLATESTROUNDRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryLatestRoundResponse)
  })
_sym_db.RegisterMessage(QueryLatestRoundResponse)

QueryLatestTransmissionDetailsRequest = _reflection.GeneratedProtocolMessageType('QueryLatestTransmissionDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLATESTTRANSMISSIONDETAILSREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryLatestTransmissionDetailsRequest)
  })
_sym_db.RegisterMessage(QueryLatestTransmissionDetailsRequest)

QueryLatestTransmissionDetailsResponse = _reflection.GeneratedProtocolMessageType('QueryLatestTransmissionDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLATESTTRANSMISSIONDETAILSRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryLatestTransmissionDetailsResponse)
  })
_sym_db.RegisterMessage(QueryLatestTransmissionDetailsResponse)

QueryOwedAmountRequest = _reflection.GeneratedProtocolMessageType('QueryOwedAmountRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYOWEDAMOUNTREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryOwedAmountRequest)
  })
_sym_db.RegisterMessage(QueryOwedAmountRequest)

QueryOwedAmountResponse = _reflection.GeneratedProtocolMessageType('QueryOwedAmountResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYOWEDAMOUNTRESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryOwedAmountResponse)
  })
_sym_db.RegisterMessage(QueryOwedAmountResponse)

QueryModuleStateRequest = _reflection.GeneratedProtocolMessageType('QueryModuleStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATEREQUEST,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryModuleStateRequest)
  })
_sym_db.RegisterMessage(QueryModuleStateRequest)

QueryModuleStateResponse = _reflection.GeneratedProtocolMessageType('QueryModuleStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATERESPONSE,
  '__module__' : 'injective.ocr.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.QueryModuleStateResponse)
  })
_sym_db.RegisterMessage(QueryModuleStateResponse)


DESCRIPTOR._options = None
_QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
_QUERYOWEDAMOUNTRESPONSE.fields_by_name['amount']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='injective.ocr.v1beta1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1328,
  serialized_end=2539,
  methods=[
  _descriptor.MethodDescriptor(
    name='Params',
    full_name='injective.ocr.v1beta1.Query.Params',
    index=0,
    containing_service=None,
    input_type=_QUERYPARAMSREQUEST,
    output_type=_QUERYPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\022\035/chainlink/ocr/v1beta1/params',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FeedConfig',
    full_name='injective.ocr.v1beta1.Query.FeedConfig',
    index=1,
    containing_service=None,
    input_type=_QUERYFEEDCONFIGREQUEST,
    output_type=_QUERYFEEDCONFIGRESPONSE,
    serialized_options=b'\202\323\344\223\002.\022,/chainlink/ocr/v1beta1/feed_config/{feed_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FeedConfigInfo',
    full_name='injective.ocr.v1beta1.Query.FeedConfigInfo',
    index=2,
    containing_service=None,
    input_type=_QUERYFEEDCONFIGINFOREQUEST,
    output_type=_QUERYFEEDCONFIGINFORESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/chainlink/ocr/v1beta1/feed_config_info/{feed_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LatestRound',
    full_name='injective.ocr.v1beta1.Query.LatestRound',
    index=3,
    containing_service=None,
    input_type=_QUERYLATESTROUNDREQUEST,
    output_type=_QUERYLATESTROUNDRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/chainlink/ocr/v1beta1/latest_round/{feed_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LatestTransmissionDetails',
    full_name='injective.ocr.v1beta1.Query.LatestTransmissionDetails',
    index=4,
    containing_service=None,
    input_type=_QUERYLATESTTRANSMISSIONDETAILSREQUEST,
    output_type=_QUERYLATESTTRANSMISSIONDETAILSRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</chainlink/ocr/v1beta1/latest_transmission_details/{feed_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OwedAmount',
    full_name='injective.ocr.v1beta1.Query.OwedAmount',
    index=5,
    containing_service=None,
    input_type=_QUERYOWEDAMOUNTREQUEST,
    output_type=_QUERYOWEDAMOUNTRESPONSE,
    serialized_options=b'\202\323\344\223\0022\0220/chainlink/ocr/v1beta1/owed_amount/{transmitter}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OcrModuleState',
    full_name='injective.ocr.v1beta1.Query.OcrModuleState',
    index=6,
    containing_service=None,
    input_type=_QUERYMODULESTATEREQUEST,
    output_type=_QUERYMODULESTATERESPONSE,
    serialized_options=b'\202\323\344\223\002%\022#/chainlink/ocr/v1beta1/module_state',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/mint/v1beta1/mint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/mint/v1beta1/mint.proto',
  package='cosmos.mint.v1beta1',
  syntax='proto3',
  serialized_options=b'Z)github.com/cosmos/cosmos-sdk/x/mint/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x63osmos/mint/v1beta1/mint.proto\x12\x13\x63osmos.mint.v1beta1\x1a\x14gogoproto/gogo.proto\"\xb2\x01\n\x06Minter\x12\x41\n\tinflation\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x65\n\x11\x61nnual_provisions\x18\x02 \x01(\tBJ\xf2\xde\x1f\x18yaml:\"annual_provisions\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xdf\x03\n\x06Params\x12\x12\n\nmint_denom\x18\x01 \x01(\t\x12m\n\x15inflation_rate_change\x18\x02 \x01(\tBN\xf2\xde\x1f\x1cyaml:\"inflation_rate_change\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12]\n\rinflation_max\x18\x03 \x01(\tBF\xf2\xde\x1f\x14yaml:\"inflation_max\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12]\n\rinflation_min\x18\x04 \x01(\tBF\xf2\xde\x1f\x14yaml:\"inflation_min\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12Y\n\x0bgoal_bonded\x18\x05 \x01(\tBD\xf2\xde\x1f\x12yaml:\"goal_bonded\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x33\n\x0f\x62locks_per_year\x18\x06 \x01(\x04\x42\x1a\xf2\xde\x1f\x16yaml:\"blocks_per_year\":\x04\x98\xa0\x1f\x00\x42+Z)github.com/cosmos/cosmos-sdk/x/mint/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_MINTER = _descriptor.Descriptor(
  name='Minter',
  full_name='cosmos.mint.v1beta1.Minter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inflation', full_name='cosmos.mint.v1beta1.Minter.inflation', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annual_provisions', full_name='cosmos.mint.v1beta1.Minter.annual_provisions', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\030yaml:\"annual_provisions\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=256,
)


_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='cosmos.mint.v1beta1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mint_denom', full_name='cosmos.mint.v1beta1.Params.mint_denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inflation_rate_change', full_name='cosmos.mint.v1beta1.Params.inflation_rate_change', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\034yaml:\"inflation_rate_change\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inflation_max', full_name='cosmos.mint.v1beta1.Params.inflation_max', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"inflation_max\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inflation_min', full_name='cosmos.mint.v1beta1.Params.inflation_min', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\024yaml:\"inflation_min\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal_bonded', full_name='cosmos.mint.v1beta1.Params.goal_bonded', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\022yaml:\"goal_bonded\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blocks_per_year', full_name='cosmos.mint.v1beta1.Params.blocks_per_year', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\026yaml:\"blocks_per_year\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\230\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=738,
)

DESCRIPTOR.message_types_by_name['Minter'] = _MINTER
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Minter = _reflection.GeneratedProtocolMessageType('Minter', (_message.Message,), {
  'DESCRIPTOR' : _MINTER,
  '__module__' : 'cosmos.mint.v1beta1.mint_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.mint.v1beta1.Minter)
  })
_sym_db.RegisterMessage(Minter)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'cosmos.mint.v1beta1.mint_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.mint.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)


DESCRIPTOR._options = None
_MINTER.fields_by_name['inflation']._options = None
_MINTER.fields_by_name['annual_provisions']._options = None
_PARAMS.fields_by_name['inflation_rate_change']._options = None
_PARAMS.fields_by_name['inflation_max']._options = None
_PARAMS.fields_by_name['inflation_min']._options = None
_PARAMS.fields_by_name['goal_bonded']._options = None
_PARAMS.fields_by_name['blocks_per_year']._options = None
_PARAMS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/peggy/v1/types.proto',
  package='injective.peggy.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1einjective/peggy/v1/types.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\":\n\x0f\x42ridgeValidator\x12\r\n\x05power\x18\x01 \x01(\x04\x12\x18\n\x10\x65thereum_address\x18\x02 \x01(\t\"\xba\x01\n\x06Valset\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x34\n\x07members\x18\x02 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x0e\n\x06height\x18\x03 \x01(\x04\x12\x45\n\rreward_amount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0creward_token\x18\x05 \x01(\t\"]\n\x1fLastObservedEthereumBlockHeight\x12\x1b\n\x13\x63osmos_block_height\x18\x01 \x01(\x04\x12\x1d\n\x15\x65thereum_block_height\x18\x02 \x01(\x04\"M\n\x0eLastClaimEvent\x12\x1c\n\x14\x65thereum_event_nonce\x18\x01 \x01(\x04\x12\x1d\n\x15\x65thereum_event_height\x18\x02 \x01(\x04\",\n\x0c\x45RC20ToDenom\x12\r\n\x05\x65rc20\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\tBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_BRIDGEVALIDATOR = _descriptor.Descriptor(
  name='BridgeValidator',
  full_name='injective.peggy.v1.BridgeValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='power', full_name='injective.peggy.v1.BridgeValidator.power', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethereum_address', full_name='injective.peggy.v1.BridgeValidator.ethereum_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=134,
)


_VALSET = _descriptor.Descriptor(
  name='Valset',
  full_name='injective.peggy.v1.Valset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.Valset.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='injective.peggy.v1.Valset.members', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='injective.peggy.v1.Valset.height', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_amount', full_name='injective.peggy.v1.Valset.reward_amount', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_token', full_name='injective.peggy.v1.Valset.reward_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=323,
)


_LASTOBSERVEDETHEREUMBLOCKHEIGHT = _descriptor.Descriptor(
  name='LastObservedEthereumBlockHeight',
  full_name='injective.peggy.v1.LastObservedEthereumBlockHeight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cosmos_block_height', full_name='injective.peggy.v1.LastObservedEthereumBlockHeight.cosmos_block_height', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethereum_block_height', full_name='injective.peggy.v1.LastObservedEthereumBlockHeight.ethereum_block_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=418,
)


_LASTCLAIMEVENT = _descriptor.Descriptor(
  name='LastClaimEvent',
  full_name='injective.peggy.v1.LastClaimEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ethereum_event_nonce', full_name='injective.peggy.v1.LastClaimEvent.ethereum_event_nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethereum_event_height', full_name='injective.peggy.v1.LastClaimEvent.ethereum_event_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=497,
)


_ERC20TODENOM = _descriptor.Descriptor(
  name='ERC20ToDenom',
  full_name='injective.peggy.v1.ERC20ToDenom',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='erc20', full_name='injective.peggy.v1.ERC20ToDenom.erc20', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.peggy.v1.ERC20ToDenom.denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=543,
)

_VALSET.fields_by_name['members'].message_type = _BRIDGEVALIDATOR
DESCRIPTOR.message_types_by_name['BridgeValidator'] = _BRIDGEVALIDATOR
DESCRIPTOR.message_types_by_name['Valset'] = _VALSET
DESCRIPTOR.message_types_by_name['LastObservedEthereumBlockHeight'] = _LASTOBSERVEDETHEREUMBLOCKHEIGHT
DESCRIPTOR.message_types_by_name['LastClaimEvent'] = _LASTCLAIMEVENT
DESCRIPTOR.message_types_by_name['ERC20ToDenom'] = _ERC20TODENOM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BridgeValidator = _reflection.GeneratedProtocolMessageType('BridgeValidator', (_message.Message,), {
  'DESCRIPTOR' : _BRIDGEVALIDATOR,
  '__module__' : 'injective.peggy.v1.types_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.BridgeValidator)
  })
_sym_db.RegisterMessage(BridgeValidator)

Valset = _reflection.GeneratedProtocolMessageType('Valset', (_message.Message,), {
  'DESCRIPTOR' : _VALSET,
  '__module__' : 'injective.peggy.v1.types_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.Valset)
  })
_sym_db.RegisterMessage(Valset)

LastObservedEthereumBlockHeight = _reflection.GeneratedProtocolMessageType('LastObservedEthereumBlockHeight', (_message.Message,), {
  'DESCRIPTOR' : _LASTOBSERVEDETHEREUMBLOCKHEIGHT,
  '__module__' : 'injective.peggy.v1.types_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.LastObservedEthereumBlockHeight)
  })
_sym_db.RegisterMessage(LastObservedEthereumBlockHeight)

LastClaimEvent = _reflection.GeneratedProtocolMessageType('LastClaimEvent', (_message.Message,), {
  'DESCRIPTOR' : _LASTCLAIMEVENT,
  '__module__' : 'injective.peggy.v1.types_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.LastClaimEvent)
  })
_sym_db.RegisterMessage(LastClaimEvent)

ERC20ToDenom = _reflection.GeneratedProtocolMessageType('ERC20ToDenom', (_message.Message,), {
  'DESCRIPTOR' : _ERC20TODENOM,
  '__module__' : 'injective.peggy.v1.types_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.ERC20ToDenom)
  })
_sym_db.RegisterMessage(ERC20ToDenom)


DESCRIPTOR._options = None
_VALSET.fields_by_name['reward_amount']._options = None
# @@protoc_insertion_point(module_scope)



import asyncio
import logging
import grpc

import pyinjective.proto.exchange.injective_spot_exchange_rpc_pb2 as spot_exchange_rpc_pb
import pyinjective.proto.exchange.injective_spot_exchange_rpc_pb2_grpc as spot_exchange_rpc_grpc
import pyinjective.proto.exchange.injective_derivative_exchange_rpc_pb2 as derivative_exchange_rpc_pb
import pyinjective.proto.exchange.injective_derivative_exchange_rpc_pb2_grpc as derivative_exchange_rpc_grpc

from decimal import *
from pyinjective.async_client import AsyncClient
from pyinjective.constant import Network

metadata_template = """[{}]
description = '{} {} {}'
base = {}
quote = {}
min_price_tick_size = {}
min_display_price_tick_size = {}
min_quantity_tick_size = {}
min_display_quantity_tick_size = {}

"""

symbol_template = """[{}]
peggy_denom = {}
decimals = {}

"""

testnet_denom_output = ''
mainnet_denom_output = ''

async def fetch_denom(network) -> str:
    denom_output = ''
    symbols = {}

    # fetch meta data for spot markets
    client = AsyncClient(network, insecure=False)
    status = 'active'
    mresp = await client.get_spot_markets(market_status=status)
    for market in mresp.markets:
        # append symbols to dict
        if market.base_token_meta.SerializeToString() != '':
            symbols[market.base_token_meta.symbol] = (market.base_denom, market.base_token_meta.decimals)

        if market.quote_token_meta.SerializeToString() != '':
            symbols[market.quote_token_meta.symbol] = (market.base_denom, market.quote_token_meta.decimals)

        # format into ini entry
        min_display_price_tick_size = float(market.min_price_tick_size) / pow(10, market.quote_token_meta.decimals -  market.base_token_meta.decimals)
        min_display_quantity_tick_size = float(market.min_quantity_tick_size) / pow(10, market.base_token_meta.decimals)
        config = metadata_template.format(
            market.market_id,
            network.string().capitalize(), 'Spot', market.ticker,
            market.base_token_meta.decimals,
            market.quote_token_meta.decimals,
            market.min_price_tick_size,
            min_display_price_tick_size,
            market.min_quantity_tick_size,
            min_display_quantity_tick_size
            )
        denom_output += config

    # fetch meta data for derivative markets
    client = AsyncClient(network, insecure=False)
    status = 'active'
    mresp = await client.get_derivative_markets(market_status=status)
    for market in mresp.markets:
        # append symbols to dict
        if market.quote_token_meta.SerializeToString() != '':
            symbols[market.quote_token_meta.symbol] = (market.quote_denom, market.quote_token_meta.decimals)

            # format into ini entry
        min_display_price_tick_size = float(market.min_price_tick_size) / pow(10, market.quote_token_meta.decimals)
        config = metadata_template.format(
            market.market_id,
            network.string().capitalize(), 'Derivative', market.ticker,
            0,
            market.quote_token_meta.decimals,
            market.min_price_tick_size,
            min_display_price_tick_size,
            market.min_quantity_tick_size,
            market.min_quantity_tick_size
        )
        denom_output += config

    # format into ini entry
    for key in symbols:
        peggy_id, decimals = symbols[key]
        symbol = symbol_template.format(key, peggy_id, decimals)
        denom_output += symbol

    return denom_output

async def main() -> None:
    testnet = Network.testnet()
    data = await fetch_denom(testnet)
    with open("denoms_testnet.ini", "w") as text_file:
        text_file.write(data)

    mainnet = Network.mainnet()
    data = await fetch_denom(mainnet)
    with open("denoms_mainnet.ini", "w") as text_file:
        text_file.write(data)

if __name__ == '__main__':
    logging.basicConfig(level=logging.INFO)
    asyncio.get_event_loop().run_until_complete(main())



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from cosmos.upgrade.v1beta1 import query_pb2 as cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC upgrade querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CurrentPlan = channel.unary_unary(
                '/cosmos.upgrade.v1beta1.Query/CurrentPlan',
                request_serializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryCurrentPlanRequest.SerializeToString,
                response_deserializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryCurrentPlanResponse.FromString,
                )
        self.AppliedPlan = channel.unary_unary(
                '/cosmos.upgrade.v1beta1.Query/AppliedPlan',
                request_serializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryAppliedPlanRequest.SerializeToString,
                response_deserializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryAppliedPlanResponse.FromString,
                )
        self.UpgradedConsensusState = channel.unary_unary(
                '/cosmos.upgrade.v1beta1.Query/UpgradedConsensusState',
                request_serializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryUpgradedConsensusStateRequest.SerializeToString,
                response_deserializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryUpgradedConsensusStateResponse.FromString,
                )
        self.ModuleVersions = channel.unary_unary(
                '/cosmos.upgrade.v1beta1.Query/ModuleVersions',
                request_serializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryModuleVersionsRequest.SerializeToString,
                response_deserializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryModuleVersionsResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC upgrade querier service.
    """

    def CurrentPlan(self, request, context):
        """CurrentPlan queries the current upgrade plan.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AppliedPlan(self, request, context):
        """AppliedPlan queries a previously applied upgrade plan by its name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpgradedConsensusState(self, request, context):
        """UpgradedConsensusState queries the consensus state that will serve
        as a trusted kernel for the next version of this chain. It will only be
        stored at the last height of this chain.
        UpgradedConsensusState RPC not supported with legacy querier
        This rpc is deprecated now that IBC has its own replacement
        (https://github.com/cosmos/ibc-go/blob/2c880a22e9f9cc75f62b527ca94aa75ce1106001/proto/ibc/core/client/v1/query.proto#L54)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModuleVersions(self, request, context):
        """ModuleVersions queries the list of module versions from state.

        Since: cosmos-sdk 0.43
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CurrentPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.CurrentPlan,
                    request_deserializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryCurrentPlanRequest.FromString,
                    response_serializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryCurrentPlanResponse.SerializeToString,
            ),
            'AppliedPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.AppliedPlan,
                    request_deserializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryAppliedPlanRequest.FromString,
                    response_serializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryAppliedPlanResponse.SerializeToString,
            ),
            'UpgradedConsensusState': grpc.unary_unary_rpc_method_handler(
                    servicer.UpgradedConsensusState,
                    request_deserializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryUpgradedConsensusStateRequest.FromString,
                    response_serializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryUpgradedConsensusStateResponse.SerializeToString,
            ),
            'ModuleVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ModuleVersions,
                    request_deserializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryModuleVersionsRequest.FromString,
                    response_serializer=cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryModuleVersionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.upgrade.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC upgrade querier service.
    """

    @staticmethod
    def CurrentPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.upgrade.v1beta1.Query/CurrentPlan',
            cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryCurrentPlanRequest.SerializeToString,
            cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryCurrentPlanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AppliedPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.upgrade.v1beta1.Query/AppliedPlan',
            cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryAppliedPlanRequest.SerializeToString,
            cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryAppliedPlanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpgradedConsensusState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.upgrade.v1beta1.Query/UpgradedConsensusState',
            cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryUpgradedConsensusStateRequest.SerializeToString,
            cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryUpgradedConsensusStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ModuleVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.upgrade.v1beta1.Query/ModuleVersions',
            cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryModuleVersionsRequest.SerializeToString,
            cosmos_dot_upgrade_dot_v1beta1_dot_query__pb2.QueryModuleVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/ocr/v1beta1/genesis.proto',
  package='injective.ocr.v1beta1',
  syntax='proto3',
  serialized_options=b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#injective/ocr/v1beta1/genesis.proto\x12\x15injective.ocr.v1beta1\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xed\x04\n\x0cGenesisState\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x37\n\x0c\x66\x65\x65\x64_configs\x18\x02 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedConfig\x12I\n\x17latest_epoch_and_rounds\x18\x03 \x03(\x0b\x32(.injective.ocr.v1beta1.FeedEpochAndRound\x12\x43\n\x12\x66\x65\x65\x64_transmissions\x18\x04 \x03(\x0b\x32\'.injective.ocr.v1beta1.FeedTransmission\x12X\n\x1blatest_aggregator_round_ids\x18\x05 \x03(\x0b\x32\x33.injective.ocr.v1beta1.FeedLatestAggregatorRoundIDs\x12\x37\n\x0creward_pools\x18\x06 \x03(\x0b\x32!.injective.ocr.v1beta1.RewardPool\x12\x42\n\x17\x66\x65\x65\x64_observation_counts\x18\x07 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedCounts\x12\x43\n\x18\x66\x65\x65\x64_transmission_counts\x18\x08 \x03(\x0b\x32!.injective.ocr.v1beta1.FeedCounts\x12\x43\n\x12pending_payeeships\x18\t \x03(\x0b\x32\'.injective.ocr.v1beta1.PendingPayeeship\"^\n\x10\x46\x65\x65\x64Transmission\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x39\n\x0ctransmission\x18\x02 \x01(\x0b\x32#.injective.ocr.v1beta1.Transmission\"c\n\x11\x46\x65\x65\x64\x45pochAndRound\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12=\n\x0f\x65poch_and_round\x18\x02 \x01(\x0b\x32$.injective.ocr.v1beta1.EpochAndRound\"L\n\x1c\x46\x65\x65\x64LatestAggregatorRoundIDs\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x1b\n\x13\x61ggregator_round_id\x18\x02 \x01(\x04\"N\n\nRewardPool\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12/\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"K\n\nFeedCounts\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12,\n\x06\x63ounts\x18\x02 \x03(\x0b\x32\x1c.injective.ocr.v1beta1.Count\"\'\n\x05\x43ount\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"P\n\x10PendingPayeeship\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\t\x12\x13\n\x0btransmitter\x18\x02 \x01(\t\x12\x16\n\x0eproposed_payee\x18\x03 \x01(\tBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3'
  ,
  dependencies=[injective_dot_ocr_dot_v1beta1_dot_ocr__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='injective.ocr.v1beta1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.ocr.v1beta1.GenesisState.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_configs', full_name='injective.ocr.v1beta1.GenesisState.feed_configs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_epoch_and_rounds', full_name='injective.ocr.v1beta1.GenesisState.latest_epoch_and_rounds', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_transmissions', full_name='injective.ocr.v1beta1.GenesisState.feed_transmissions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_aggregator_round_ids', full_name='injective.ocr.v1beta1.GenesisState.latest_aggregator_round_ids', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward_pools', full_name='injective.ocr.v1beta1.GenesisState.reward_pools', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_observation_counts', full_name='injective.ocr.v1beta1.GenesisState.feed_observation_counts', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feed_transmission_counts', full_name='injective.ocr.v1beta1.GenesisState.feed_transmission_counts', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_payeeships', full_name='injective.ocr.v1beta1.GenesisState.pending_payeeships', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=771,
)


_FEEDTRANSMISSION = _descriptor.Descriptor(
  name='FeedTransmission',
  full_name='injective.ocr.v1beta1.FeedTransmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.FeedTransmission.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmission', full_name='injective.ocr.v1beta1.FeedTransmission.transmission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=773,
  serialized_end=867,
)


_FEEDEPOCHANDROUND = _descriptor.Descriptor(
  name='FeedEpochAndRound',
  full_name='injective.ocr.v1beta1.FeedEpochAndRound',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.FeedEpochAndRound.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch_and_round', full_name='injective.ocr.v1beta1.FeedEpochAndRound.epoch_and_round', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=968,
)


_FEEDLATESTAGGREGATORROUNDIDS = _descriptor.Descriptor(
  name='FeedLatestAggregatorRoundIDs',
  full_name='injective.ocr.v1beta1.FeedLatestAggregatorRoundIDs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.FeedLatestAggregatorRoundIDs.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregator_round_id', full_name='injective.ocr.v1beta1.FeedLatestAggregatorRoundIDs.aggregator_round_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=970,
  serialized_end=1046,
)


_REWARDPOOL = _descriptor.Descriptor(
  name='RewardPool',
  full_name='injective.ocr.v1beta1.RewardPool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.RewardPool.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.ocr.v1beta1.RewardPool.amount', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1126,
)


_FEEDCOUNTS = _descriptor.Descriptor(
  name='FeedCounts',
  full_name='injective.ocr.v1beta1.FeedCounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.FeedCounts.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counts', full_name='injective.ocr.v1beta1.FeedCounts.counts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1203,
)


_COUNT = _descriptor.Descriptor(
  name='Count',
  full_name='injective.ocr.v1beta1.Count',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='injective.ocr.v1beta1.Count.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='injective.ocr.v1beta1.Count.count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1205,
  serialized_end=1244,
)


_PENDINGPAYEESHIP = _descriptor.Descriptor(
  name='PendingPayeeship',
  full_name='injective.ocr.v1beta1.PendingPayeeship',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_id', full_name='injective.ocr.v1beta1.PendingPayeeship.feed_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='injective.ocr.v1beta1.PendingPayeeship.transmitter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposed_payee', full_name='injective.ocr.v1beta1.PendingPayeeship.proposed_payee', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1246,
  serialized_end=1326,
)

_GENESISSTATE.fields_by_name['params'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._PARAMS
_GENESISSTATE.fields_by_name['feed_configs'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._FEEDCONFIG
_GENESISSTATE.fields_by_name['latest_epoch_and_rounds'].message_type = _FEEDEPOCHANDROUND
_GENESISSTATE.fields_by_name['feed_transmissions'].message_type = _FEEDTRANSMISSION
_GENESISSTATE.fields_by_name['latest_aggregator_round_ids'].message_type = _FEEDLATESTAGGREGATORROUNDIDS
_GENESISSTATE.fields_by_name['reward_pools'].message_type = _REWARDPOOL
_GENESISSTATE.fields_by_name['feed_observation_counts'].message_type = _FEEDCOUNTS
_GENESISSTATE.fields_by_name['feed_transmission_counts'].message_type = _FEEDCOUNTS
_GENESISSTATE.fields_by_name['pending_payeeships'].message_type = _PENDINGPAYEESHIP
_FEEDTRANSMISSION.fields_by_name['transmission'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._TRANSMISSION
_FEEDEPOCHANDROUND.fields_by_name['epoch_and_round'].message_type = injective_dot_ocr_dot_v1beta1_dot_ocr__pb2._EPOCHANDROUND
_REWARDPOOL.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_FEEDCOUNTS.fields_by_name['counts'].message_type = _COUNT
DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
DESCRIPTOR.message_types_by_name['FeedTransmission'] = _FEEDTRANSMISSION
DESCRIPTOR.message_types_by_name['FeedEpochAndRound'] = _FEEDEPOCHANDROUND
DESCRIPTOR.message_types_by_name['FeedLatestAggregatorRoundIDs'] = _FEEDLATESTAGGREGATORROUNDIDS
DESCRIPTOR.message_types_by_name['RewardPool'] = _REWARDPOOL
DESCRIPTOR.message_types_by_name['FeedCounts'] = _FEEDCOUNTS
DESCRIPTOR.message_types_by_name['Count'] = _COUNT
DESCRIPTOR.message_types_by_name['PendingPayeeship'] = _PENDINGPAYEESHIP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

FeedTransmission = _reflection.GeneratedProtocolMessageType('FeedTransmission', (_message.Message,), {
  'DESCRIPTOR' : _FEEDTRANSMISSION,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.FeedTransmission)
  })
_sym_db.RegisterMessage(FeedTransmission)

FeedEpochAndRound = _reflection.GeneratedProtocolMessageType('FeedEpochAndRound', (_message.Message,), {
  'DESCRIPTOR' : _FEEDEPOCHANDROUND,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.FeedEpochAndRound)
  })
_sym_db.RegisterMessage(FeedEpochAndRound)

FeedLatestAggregatorRoundIDs = _reflection.GeneratedProtocolMessageType('FeedLatestAggregatorRoundIDs', (_message.Message,), {
  'DESCRIPTOR' : _FEEDLATESTAGGREGATORROUNDIDS,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.FeedLatestAggregatorRoundIDs)
  })
_sym_db.RegisterMessage(FeedLatestAggregatorRoundIDs)

RewardPool = _reflection.GeneratedProtocolMessageType('RewardPool', (_message.Message,), {
  'DESCRIPTOR' : _REWARDPOOL,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.RewardPool)
  })
_sym_db.RegisterMessage(RewardPool)

FeedCounts = _reflection.GeneratedProtocolMessageType('FeedCounts', (_message.Message,), {
  'DESCRIPTOR' : _FEEDCOUNTS,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.FeedCounts)
  })
_sym_db.RegisterMessage(FeedCounts)

Count = _reflection.GeneratedProtocolMessageType('Count', (_message.Message,), {
  'DESCRIPTOR' : _COUNT,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.Count)
  })
_sym_db.RegisterMessage(Count)

PendingPayeeship = _reflection.GeneratedProtocolMessageType('PendingPayeeship', (_message.Message,), {
  'DESCRIPTOR' : _PENDINGPAYEESHIP,
  '__module__' : 'injective.ocr.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.ocr.v1beta1.PendingPayeeship)
  })
_sym_db.RegisterMessage(PendingPayeeship)


DESCRIPTOR._options = None
_GENESISSTATE.fields_by_name['params']._options = None
_REWARDPOOL.fields_by_name['amount']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from exchange import injective_spot_exchange_rpc_pb2 as exchange_dot_injective__spot__exchange__rpc__pb2


class InjectiveSpotExchangeRPCStub(object):
    """InjectiveSpotExchangeRPC defines gRPC API of Spot Exchange provider.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Markets = channel.unary_unary(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Markets',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.MarketsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.MarketsResponse.FromString,
                )
        self.Market = channel.unary_unary(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Market',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.MarketRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.MarketResponse.FromString,
                )
        self.StreamMarkets = channel.unary_stream(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/StreamMarkets',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamMarketsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamMarketsResponse.FromString,
                )
        self.Orderbook = channel.unary_unary(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Orderbook',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrderbookRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrderbookResponse.FromString,
                )
        self.Orderbooks = channel.unary_unary(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Orderbooks',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrderbooksRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrderbooksResponse.FromString,
                )
        self.StreamOrderbook = channel.unary_stream(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/StreamOrderbook',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrderbookRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrderbookResponse.FromString,
                )
        self.Orders = channel.unary_unary(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Orders',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrdersRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrdersResponse.FromString,
                )
        self.StreamOrders = channel.unary_stream(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/StreamOrders',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersResponse.FromString,
                )
        self.Trades = channel.unary_unary(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Trades',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.TradesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.TradesResponse.FromString,
                )
        self.StreamTrades = channel.unary_stream(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/StreamTrades',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamTradesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamTradesResponse.FromString,
                )
        self.SubaccountOrdersList = channel.unary_unary(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/SubaccountOrdersList',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountOrdersListRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountOrdersListResponse.FromString,
                )
        self.SubaccountTradesList = channel.unary_unary(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/SubaccountTradesList',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountTradesListRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountTradesListResponse.FromString,
                )
        self.OrdersHistory = channel.unary_unary(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/OrdersHistory',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrdersHistoryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrdersHistoryResponse.FromString,
                )
        self.StreamOrdersHistory = channel.unary_stream(
                '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/StreamOrdersHistory',
                request_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersHistoryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersHistoryResponse.FromString,
                )


class InjectiveSpotExchangeRPCServicer(object):
    """InjectiveSpotExchangeRPC defines gRPC API of Spot Exchange provider.
    """

    def Markets(self, request, context):
        """Get a list of Spot Markets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Market(self, request, context):
        """Get details of a single spot market
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamMarkets(self, request, context):
        """Stream live updates of selected spot markets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Orderbook(self, request, context):
        """Orderbook of a Spot Market
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Orderbooks(self, request, context):
        """Orderbook of Spot Markets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamOrderbook(self, request, context):
        """Stream live updates of selected spot market orderbook
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Orders(self, request, context):
        """Orders of a Spot Market
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamOrders(self, request, context):
        """Stream updates to individual orders of a Spot Market
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Trades(self, request, context):
        """Trades of a Spot Market
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamTrades(self, request, context):
        """Stream newly executed trades from Spot Market
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubaccountOrdersList(self, request, context):
        """List orders posted from this subaccount
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubaccountTradesList(self, request, context):
        """List trades executed by this subaccount
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OrdersHistory(self, request, context):
        """Lists history orders posted from this subaccount
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamOrdersHistory(self, request, context):
        """Stream updates to historical orders of a spot Market
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveSpotExchangeRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Markets': grpc.unary_unary_rpc_method_handler(
                    servicer.Markets,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.MarketsRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.MarketsResponse.SerializeToString,
            ),
            'Market': grpc.unary_unary_rpc_method_handler(
                    servicer.Market,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.MarketRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.MarketResponse.SerializeToString,
            ),
            'StreamMarkets': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamMarkets,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamMarketsRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamMarketsResponse.SerializeToString,
            ),
            'Orderbook': grpc.unary_unary_rpc_method_handler(
                    servicer.Orderbook,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrderbookRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrderbookResponse.SerializeToString,
            ),
            'Orderbooks': grpc.unary_unary_rpc_method_handler(
                    servicer.Orderbooks,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrderbooksRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrderbooksResponse.SerializeToString,
            ),
            'StreamOrderbook': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamOrderbook,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrderbookRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrderbookResponse.SerializeToString,
            ),
            'Orders': grpc.unary_unary_rpc_method_handler(
                    servicer.Orders,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrdersRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrdersResponse.SerializeToString,
            ),
            'StreamOrders': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamOrders,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersResponse.SerializeToString,
            ),
            'Trades': grpc.unary_unary_rpc_method_handler(
                    servicer.Trades,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.TradesRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.TradesResponse.SerializeToString,
            ),
            'StreamTrades': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamTrades,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamTradesRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamTradesResponse.SerializeToString,
            ),
            'SubaccountOrdersList': grpc.unary_unary_rpc_method_handler(
                    servicer.SubaccountOrdersList,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountOrdersListRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountOrdersListResponse.SerializeToString,
            ),
            'SubaccountTradesList': grpc.unary_unary_rpc_method_handler(
                    servicer.SubaccountTradesList,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountTradesListRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountTradesListResponse.SerializeToString,
            ),
            'OrdersHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.OrdersHistory,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrdersHistoryRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.OrdersHistoryResponse.SerializeToString,
            ),
            'StreamOrdersHistory': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamOrdersHistory,
                    request_deserializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersHistoryRequest.FromString,
                    response_serializer=exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersHistoryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_spot_exchange_rpc.InjectiveSpotExchangeRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InjectiveSpotExchangeRPC(object):
    """InjectiveSpotExchangeRPC defines gRPC API of Spot Exchange provider.
    """

    @staticmethod
    def Markets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Markets',
            exchange_dot_injective__spot__exchange__rpc__pb2.MarketsRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.MarketsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Market(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Market',
            exchange_dot_injective__spot__exchange__rpc__pb2.MarketRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.MarketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamMarkets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/StreamMarkets',
            exchange_dot_injective__spot__exchange__rpc__pb2.StreamMarketsRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.StreamMarketsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Orderbook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Orderbook',
            exchange_dot_injective__spot__exchange__rpc__pb2.OrderbookRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.OrderbookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Orderbooks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Orderbooks',
            exchange_dot_injective__spot__exchange__rpc__pb2.OrderbooksRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.OrderbooksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamOrderbook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/StreamOrderbook',
            exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrderbookRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrderbookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Orders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Orders',
            exchange_dot_injective__spot__exchange__rpc__pb2.OrdersRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.OrdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/StreamOrders',
            exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Trades(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/Trades',
            exchange_dot_injective__spot__exchange__rpc__pb2.TradesRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.TradesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamTrades(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/StreamTrades',
            exchange_dot_injective__spot__exchange__rpc__pb2.StreamTradesRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.StreamTradesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubaccountOrdersList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/SubaccountOrdersList',
            exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountOrdersListRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountOrdersListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubaccountTradesList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/SubaccountTradesList',
            exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountTradesListRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.SubaccountTradesListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OrdersHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/OrdersHistory',
            exchange_dot_injective__spot__exchange__rpc__pb2.OrdersHistoryRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.OrdersHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamOrdersHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_spot_exchange_rpc.InjectiveSpotExchangeRPC/StreamOrdersHistory',
            exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersHistoryRequest.SerializeToString,
            exchange_dot_injective__spot__exchange__rpc__pb2.StreamOrdersHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
